﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace ThinkGeoRefreshIssues
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;
            wpfMap1.CurrentExtent = new RectangleShape(0, 100, 100, 0);
            wpfMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.White);

            InMemoryFeatureLayer inMemoryLayer = new InMemoryFeatureLayer();
            inMemoryLayer.InternalFeatures.Add("Polygon", new Feature("POLYGON((10 60,40 70,30 85, 10 60))", "Polygon"));
            inMemoryLayer.InternalFeatures.Add("Rectangle", new Feature(new RectangleShape(65, 30, 95, 15).GetWellKnownText(), "Rectangle"));

            inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(100, GeoColor.StandardColors.RoyalBlue);
            inMemoryLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay inmemoryOverlay = new LayerOverlay();
            inmemoryOverlay.TileType = TileType.MultipleTile;
            inmemoryOverlay.Layers.Add("InMemoryFeatureLayer", inMemoryLayer);
            inmemoryOverlay.Drawn += OverlayOnDrawn;
            wpfMap1.Overlays.Add("InmemoryOverlay", inmemoryOverlay);

            wpfMap1.Refresh();
        }

        private int drawncounter = 0;

        private void RefreshFull_OnClick(object sender, RoutedEventArgs e)
        {
            CounterTextBlock.Visibility = Visibility.Visible;
            LayerOverlay overlay = (LayerOverlay)wpfMap1.Overlays["InmemoryOverlay"];
            drawncounter = 0;
            overlay.Refresh();
        }

        private void OverlayOnDrawn(object sender, DrawnOverlayEventArgs drawnOverlayEventArgs)
        {
            drawncounter++;
            CounterTextBlock.Text = "Overlay.Drawn event triggered " + drawncounter + " times";
        }

        private void RefreshRegion_OnClick(object sender, RoutedEventArgs e)
        {
            CounterTextBlock.Visibility = Visibility.Visible;
            LayerOverlay overlay = (LayerOverlay)wpfMap1.Overlays["InmemoryOverlay"];
            drawncounter = 0;
            RectangleShape extent = (RectangleShape)wpfMap1.CurrentExtent.CloneDeep();
            extent.ScaleDown(40);
            overlay.Refresh(extent);
        }
    }
}
